@@ -56,7 +56,9 @@ def _value2index(a, a_min, da):
 def _format_floats(x):
     """Format floats in the statistsics table"""
     if isinstance(x, float):
-        if x > 0.09 or x < -0.09:
+        if x < 0.000001:
+            return "~ 0"
+        elif x > 0.09 or 0.000001< x < -0.09:
             return np.format_float_positional(x, precision=2)
         else:
             return np.format_float_scientific(x, precision=2)
